@@ -13,7 +13,7 @@ use Perinci::Sub::Util qw(gen_modified_sub);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-10-30'; # DATE
 our $DIST = 'App-FileSortUtils'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our %SPEC;
 
@@ -277,8 +277,10 @@ sub sort_files {
         @sorted_files = @res;
     }
 
-    unless ($args{detail}) {
-        @sorted_files = map { $_->{name} } @sorted_files;
+    if ($args{detail}) {
+        for (@sorted_files) { $_->{dir} = $dir }
+    } else {
+        @sorted_files = map { ($dir eq '.' ? '' : $dir eq '/' ? '/' : "$dir/") . $_->{name} } @sorted_files;
     }
 
     [200, "OK", \@sorted_files];
@@ -580,7 +582,7 @@ App::FileSortUtils - Utilities related to sorting files in a directory
 
 =head1 VERSION
 
-This document describes version 0.003 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-10-30.
+This document describes version 0.004 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-10-30.
 
 =head1 DESCRIPTION
 
